import requests

base = 'http://127.0.0.1:23456/'

pc_data = {'cpu': 'AMD Ryzen',
           'ram': 16, 'ssd': 512, 'price': 1000}

response = requests.post(base + 'pcs/1', pc_data)
print(response.json())


# response = requests.delete(base + 'clients/2')
# print(response.json())


from flask import Flask, jsonify, request
from flask_restful import reqparse, abort, Api, Resource
from src_server.Helpers import *
from src_server.DatabaseManager import *

parser = Parser().parser
red = RedisController().red

class PortHandler(Resource):
    def post(self):
        request.get_json(force=True)
        args = parser.parse_args()
        username = str(args['username'])
        if red.get(username) != None:
            client_port = int(str(red.get(username))[2:-1])
            return jsonify(port=client_port)
        else:
            response = jsonify(dict(error='User Does not Exist'))
            response.status_code = 404
            return response


from src_server.Globals import *

class EnpointBuilder:

    def __init__(self) -> None:
        self._globalConsts = GlobalConsts()
        self._persistentPath = self._globalConsts.persistentApiPath
        self.__path = self._persistentPath
        pass

    def addParam(self, param):
        self.__path += ("/" + param)
        return self

    def build(self):
        tmpPath = self.__path
        self.__path = self._persistentPath
        return tmpPath


from .globalConsts import *


class ConnectionData:

    def __init__(self) -> None:

        self._GlobalConsts = GlobalConsts()

        self.connectionHostToServer = ('127.0.0.1', self._GlobalConsts.server_port);

        self.connectionHostToPeer = ('127.0.0.1', self._GlobalConsts.server_port)

        self.connectionSelfHost = ('127.0.0.1', self._GlobalConsts.server_port)




from sqlite3 import *

conn = sqlite3.connect(db_file) #.db 

cursor = conn.cursor()

cursor.execute(query_string)

cursor.execute('update user set name = ? where id = ?', [name, user_id])

rows = cursor.fetchall()


from file_read import *
from restful_net import *
from tcp_net import *
from udp_net import *
from client import *
from server_restful import *
from socketserver import *
from sqlite_net import *
from src import *
from src_server import *
from requests_net import *


import socket
import datetime
import time
import pickle
import threading
import sys
from src import *
import aiohttp
import asyncio


client_sock = None

connectionData = ConnectionData()
globalConsts = GlobalConsts()
processor = Processor()

async def initUser():

    global selfUsername
    username = input("Input your username to enter to the chat: ")
    selfUsername = username
    data = {"username": selfUsername}
    async with aiohttp.ClientSession(headers={"Content-Type":"application/json"}) as session:

        authUrl = globalConsts.apiPath + "/auth"
        async with session.post(authUrl, json=data) as resp:
            selfPort = await resp.json()
            selfPort = selfPort["port"]
            processor.processMessageAuth(selfPort, connectionData, self_server)


def self_server(connectionSelfHost):
    global client_sock

    client_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    client_sock.bind(connectionSelfHost)
    peerListenerThread.start()

def peerListener(stop):

    global client_sock

    while True:
        data, address = client_sock.recvfrom(globalConsts.MAX_BYTES)
        processor.processMessage(data)

        if stop():
            break

def client_async(stop_threads):
    asyncio.run(client(stop_threads))

async def client(stop):
    
    global selfUsername
    global client_sock

    while True:
        inp = input()
        try:
            inp = inp.strip()
            lst = inp.split(":")
            reciever = lst[0].strip()
            message_to_send = lst[1].strip()
            data = {"username": reciever}
            async with aiohttp.ClientSession(headers={"Content-Type":"application/json"}) as session:
                portRequest = globalConsts.apiPath + "/recieverPort"
                async with session.post(portRequest, json=data) as resp:
                    recieverPort = await resp.json()
                    recieverPort = recieverPort["port"]
                    new_obj = {"username": selfUsername, "message": message_to_send}
                    processor.processSendMessageToPort(client_sock, connectionData, recieverPort, new_obj)
        except IndexError:
            print("\nERROR: Invalid Format!\n")
        except Exception as err:
            print("\n*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*\n" + str(err) + "\n")

        if stop():
            break


peerListenerThread = None
clientThread = None
stop_threads = False

async def main():

    global stop_threads
    global peerListenerThread
    global clientThread

    stop_threads = False
    peerListenerThread = threading.Thread(target=peerListener, args =(lambda : stop_threads, ))
    clientThread = threading.Thread(target=client_async, args =(lambda : stop_threads, ))
    await initUser();
    try:
        clientThread.start()
    except:
        print ("Error: unable to start thread")

asyncio.run(main())


import socket
import datetime
import time
import pickle
import threading
import redis
from flask import Flask, jsonify, request
from flask_restful import reqparse, abort, Api, Resource
from src_server import *

app = Flask(__name__)
api = Api(app)
endpointBuilder = EnpointBuilder()
globalConsts = GlobalConsts()
mainConfiguration = MainConfiguration()

mainConfiguration.configureApp();

api.add_resource(Auth, endpointBuilder.addParam("auth").build())
api.add_resource(PortHandler, endpointBuilder.addParam("recieverPort").build())

if __name__ == '__main__':
    app.run(host='0.0.0.0', port=globalConsts.server_port ,debug=True)